@@ -10,7 +10,7 @@ void presmestim(double *x, int *nx, double *t, int *nt, double *bw, int *nkernel
   case 1:{
     for (i = 0; i < *nx; i++) {
       psest[i] = 1;
-      for (j = 0; (t[j] <= x[i]) && (j < *nt); j++)
+      for (j = 0; (j < *nt) && (t[j] <= x[i]); j++)
 	psest[i] *= 1 - phat[j] / (*nt - j);
     }
     break;
@@ -19,7 +19,7 @@ void presmestim(double *x, int *nx, double *t, int *nt, double *bw, int *nkernel
   case 2:{
     for (i = 0; i < *nx; i++){
       psest[i] = 0;
-      for (j = 0; (t[j] <= x[i]) && (j < *nt); j++) {
+      for (j = 0; (j < *nt) && (t[j] <= x[i]); j++) {
 	if (dup[j] == 1)
 	  counter++;
 	else 
